<!DOCTYPE html>
<html>

<head>
	<meta charset="utf-8"> 
	<link rel="stylesheet" href="http://cdn.static.runoob.com/libs/bootstrap/3.3.7/css/bootstrap.min.css">
	<script src="http://cdn.static.runoob.com/libs/jquery/2.1.1/jquery.min.js"></script>
	<script src="http://cdn.static.runoob.com/libs/bootstrap/3.3.7/js/bootstrap.min.js"></script>
</head>
<body>
  <ul id="myTab" class="nav nav-tabs">
 {% for name in all_names %} 
 <li class="dropdown"><a href="#{{ name }}" data-toggle="tab">{{ name }}</a></li>
 {% endfor %}
</ul>

{% if error_message %}<p><strong>{{ error_message }}</strong></p>{% endif %}

<div id="myTabContent" class="tab-content">
 {% for t in all_t %}  
	<div class="tab-pane fade" id="{{ t.current_name }}">
    <form action="{% url 'bob:gogo' t.current_name %}" method="post" 
          enctype="multipart/form-data" accept-charset="utf-8">
     {% csrf_token %}
     {% for field in t.current_fields %}
        <label for="name">{{ field }}</label>
        <input type="text" name="{{ field }}" />
     {% endfor %}
        <input type="file" name="input-file">  
        <input type="submit" value="Save" />
    </form>
    <a href="{% url 'bob:bobtasks' t.current_name %}">view tasks</a>
  </div>
 {% endfor %}
</div>

</body>
</html>
