# Generated by Django 2.0.2 on 2018-02-22 09:01

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Tasks',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=32)),
                ('cdate', models.DateTimeField(verbose_name='date create')),
                ('fields', models.CharField(max_length=2048)),
            ],
        ),
    ]
