<!DOCTYPE html>
<html>
<head>
	<meta charset="utf-8"> 
	<title>BOBTASKS</title>
	<link rel="stylesheet" href="http://cdn.static.runoob.com/libs/bootstrap/3.3.7/css/bootstrap.min.css">  
	<script src="http://cdn.static.runoob.com/libs/jquery/2.1.1/jquery.min.js"></script>
	<script src="http://cdn.static.runoob.com/libs/bootstrap/3.3.7/js/bootstrap.min.js"></script>
</head>
<body>

<table class="table">
	<caption>{{ name }}</caption>
   <thead>
      <tr>
         <th>Task-paras</th>
         <th>Task-status</th>
         <th>Task-udate</th>
         <th>Task-input-file</th>
         <th>Task-output-file</th>
         <th>Task-output</th>
      </tr>
   </thead>
   <tbody>
   {% for task in tasks %}
      <tr>
         <td>{{ task.para }}</td>
         <td>{{ task.status }}</td>
         <td>{{ task.udate }}</td>
         <td>{{ task.input_file }}</td>
         {% if task.output_file %}
            <td><a href="{% url 'bob:file_download' name 'output' task.output_file %}">{{ task.output_file }}</a></td>
         {% else %}
            <td>{{ task.output_file }}</td>
         {% endif %}
         <td>{{ task.output }}</td>
      </tr>
   {% endfor %}
   </tbody>
</table>

</body>
</html>
